@@ -1,11 +1,14 @@
 import dataclasses
 import inspect
+
 import typing_inspect
 
 from autofaker.attributes import Attributes
 from autofaker.dates import DatetimeGenerator, DateGenerator, is_date_type
-from autofaker.fakes import FakeStringGenerator, StringGenerator, FakeIntegerGenerator, TypeDataGeneratorBase
 from autofaker.factory import BuiltinTypeDataGeneratorFactory
+from autofaker.fakes import TypeDataGeneratorBase
+from autofaker.enums import EnumGenerator, is_enum
+
 
 class TypeDataGenerator:
     @staticmethod
@@ -13,21 +16,21 @@ class TypeDataGenerator:
         type_name = TypeDataGenerator._get_type_name(t).lower()
         if BuiltinTypeDataGeneratorFactory.is_supported(type_name):
             return BuiltinTypeDataGeneratorFactory.create(type_name, field_name, use_fake_data)
-        elif is_date_type(type_name):
+        if is_date_type(type_name):
             return TypeDataGenerator.create_datetime(type_name, field_name, use_fake_data)
-        elif type_name == 'list':
+        if type_name == 'list':
             return ListGenerator(t)
-        else:
-            return DataClassGenerator(t, use_fake_data=use_fake_data) \
-                if dataclasses.is_dataclass(t) \
-                else ClassGenerator(t, use_fake_data=use_fake_data)
-
+        if is_enum(t):
+            return EnumGenerator(t)
+        return DataClassGenerator(t, use_fake_data=use_fake_data) \
+            if dataclasses.is_dataclass(t) \
+            else ClassGenerator(t, use_fake_data=use_fake_data)
 
     @staticmethod
     def create_datetime(type_name, field_name: str = None, use_fake_data: bool = False):
         if type_name == 'datetime':
             return DatetimeGenerator()
-        elif type_name == 'date':
+        if type_name == 'date':
             return DateGenerator()
 
     @staticmethod
@@ -38,8 +41,7 @@ class TypeDataGenerator:
             attributes = dir(t)
             if '_name' in attributes:
                 return t._name
-            else:
-                return type(t).__name__
+            return type(t).__name__
 
 
 class DataClassGenerator(TypeDataGeneratorBase):
